@@ -113,9 +113,9 @@ class HelperTestDecode(unittest.TestCase):
             files = os.listdir(self.encode_dir_stage3)
             self.assertEqual(len(files), self.result['count_root_files_stage3'], 'count_root_files_stage3')
 
-    def encode_stage3(self):
+    def encode_stage3(self, *, gui=None):
         encode(self.encode_dir_stage3, self.encode_dir_stage2, version=self.version, pool=self.pool,
-               file_name=os.path.basename(self.src_file))
+               file_name=os.path.basename(self.src_file), gui=gui)
         self.assert_stage(self.decode_dir_stage2, self.encode_dir_stage2)
         if self.result:
             files = os.listdir(self.encode_dir_stage2)
@@ -237,7 +237,7 @@ def compare_file(path_decode_entry, path_encode_entry):
                             if encode_line[:-2] == decode_line:
                                 continue
                         problems += f'\n      {title:73} {i:5} {decode_line}'
-                        problems += f'\n      {"":90} {encode_line}'
+                        problems += f'\n      {"":80} {encode_line}'
                         raise NotEqualLine(problems)
                     elif decode_line.hex() != encode_line.hex():
                         a = 1
